<JSB>
/*
 * dialog.jsb    1.0 97/11/09
 *
 * Copyright (c) 1997 Netscape Communications Corporation
 *
 * Netscape grants you a non-exclusive, royalty free, license to use,
 * modify and redistribute this software in source and binary code form,
 * provided that i) this copyright notice and license appear on all copies of
 * the software; and ii) Licensee does not utilize the software in a manner
 * which is disparaging to Netscape.
 *
 * This software is provided "AS IS," without a warranty of any kind.
 * See the CDK License Agreement for additional terms and conditions.
 * garys@netscape.com
 */

   /**
    * Creates a dialog box layer which can contain arbitrary HTML.
    * Encapsulates logic for dragging the layer around, and hiding the
    * OK / CANCEL buttons during dragging operations to optimize drawing
    * performance.<p>
    *
    * In addition, the dialog box retains its open / closed state (but
    * not position) upon a resize event.
    */
   <JSB_DESCRIPTOR
        NAME="netscape.samples.widgets.dialog" DISPLAYNAME="Movable HTML Dialog"
        HELP_URL="netscape/samples/widgets/dialog_jsb.html">


   /**
    * n_s_w_ stands for netscape/samples/simple...
    * allows icon to sit in root of jar while providing
    * an (almost) proper namespace.
    */
   <JSB_ICON ICONNAME="n_s_w_dialog">


   /**
    * The title to appear in the dialog box.
    * @see dialogContent
    */
   <JSB_PROPERTY NAME="dialogTitle" DISPLAYNAME="dialog Title" TYPE="string"
        DEFAULT_VALUE="Dialog Box"> 

   /**
    * Specifies the arbitrary HTML to be displayed inside of the dialog.
    * Form fields and other items inside the content can be accessed via
    * <pre>
    * abstractDialog.win.con.document.
    * </pre>
    * @see dialogTitle
    */
   <JSB_PROPERTY NAME="dialogContent" DISPLAYNAME="dialog Content (text/html)" TYPE="string"
        DEFAULT_VALUE="Enter some text or HTML content here..."> 

   /**
    * The function to be called when the OK button is pressed.
    */
   <JSB_PROPERTY NAME="dialogOK" DISPLAYNAME="Function for dialog OK button" TYPE="string"
        DEFAULT_VALUE="//add your function here"> 

   /**
    * The X Position of the dialog (default behavior is to attempt to center
    * the dialog)
    * @see dialogY
    * @see dialogW
    * @see dialogH
    */
   <JSB_PROPERTY NAME="dialogX" DISPLAYNAME="dialog pageX cord (pixels)" TYPE="number"
        DEFAULT_VALUE="window.innerWidth / 3"> 

   /**
    * The Y Position of the dialog (default behavior is to attempt to center
    * the dialog)
    * @see dialogX
    * @see dialogW
    * @see dialogH
    */
   <JSB_PROPERTY NAME="dialogY" DISPLAYNAME="dialog pageY cord (pixels)" TYPE="number"
        DEFAULT_VALUE="window.innerHeight / 3"> 

   /**
    * The width of the dialog, which by default is determined by the content.
    * @see dialogContent
    * @see dialogH
    * @see dialogX
    * @see dialogY
    */
   <JSB_PROPERTY NAME="dialogW" DISPLAYNAME="dialog Width (pixels)" TYPE="number"
        DEFAULT_VALUE="null"> 

   /**
    * The height of the dialog, which by default is determined by the content.
    * @see dialogContent
    * @see dialogW
    * @see dialogX
    * @see dialogY
    */
   <JSB_PROPERTY NAME="dialogH" DISPLAYNAME="dialog Height (pixels)" TYPE="number"
        DEFAULT_VALUE="null"> 

   /**
    * The background color of the dialog
    * @see dialogContent
    */
   <JSB_PROPERTY NAME="dialogBG" DISPLAYNAME="dialog bgColor" TYPE="string"
        DEFAULT_VALUE="#CCCCCC"> 

   /**
    * A flag to determine if the dialog should display the OK/Cancel buttons
    */
   <JSB_PROPERTY NAME="dialogButtons" DISPLAYNAME="display dialog OK/Cancel Buttons" TYPE="boolean"
        DEFAULT_VALUE="true"> 

/* Not ready for prime time
   <JSB_PROPERTY NAME="dialogSRC" DISPLAYNAME="dialog SRC (URL)" TYPE="string"
        DEFAULT_VALUE="URL"> 
*/

   /**
    * The method to call to open the dialog box.
    */
   <JSB_METHOD NAME="openDialog" TYPE="void"> </JSB_METHOD>

   /**
    * The method to call to create a sample dialog box and open
    * it automatically
    */
   <JSB_METHOD NAME="exampleDialog" TYPE="void"> </JSB_METHOD>


   <JSB_CONSTRUCTOR>
   /**
    * netscape.samples.widgets.dialog.js
    * usable as a JSB or directly as a JS file
    */

    /**
     * Constructs a new dialog object.  The contents can
     * be queried using <b><code>abstractDialog.win.con.document</code></b>
     */
    function netscape_samples_widgets_dialog(params) {
        _netscape_samples_widgets_sysout("In constructor");

        // Properties

        // The following takes all of the parameters passed
        // to the constructor and assigns it to the newly
        // created instance object "this" which is an instance
        // of the dialog JavaScript Bean.

        this.dialogTitle = params.dialogTitle;
        this.dialogContent = params.dialogContent;
        this.dialogSRC = params.dialogSRC;
        this.dialogWinSRC = params.dialogWinSRC;
        this.dialogOK = params.dialogOK;
        this.dialogX = params.dialogX;
        this.dialogY = params.dialogY;
        this.dialogW = params.dialogW;
        this.dialogH = params.dialogH;
        this.dialogBG = params.dialogBG;
        this.dialogButtons = params.dialogButtons;

        // METHODS

        // The following attaches all of the methods
        // to the new instance object (this) -- note the
        // localization of the formal namespace fullnames
        // of the methods which then become shorthanded
        // when attached to the "this" object.  The
        // shorthand should match the non-namespace portion
        // of the formal method signature.

        this.openDialog = netscape_samples_widgets_openDialog;
        this.exampleDialog = netscape_samples_widgets_exampleDialog;
        this.okButton = netscape_samples_widgets_okButton;
        this.okButtonFocus = netscape_samples_widgets_okButtonFocus;
        this.exampleDialog = netscape_samples_widgets_exampleDialog;
        this.setDialogContent = netscape_samples_widgets_setDialogContent; 
        this.setDialogTitle = netscape_samples_widgets_setDialogTitle;
        this.setDialogOK = netscape_samples_widgets_setDialogOK; 
        this.setDialogX = netscape_samples_widgets_setDialogX;
        this.setDialogY = netscape_samples_widgets_setDialogY;
        this.setDialogW = netscape_samples_widgets_setDialogW;
        this.setDialogH = netscape_samples_widgets_setDialogH;
        this.setDialogBG = netscape_samples_widgets_setDialogBG;
        this.setDialogButtons = netscape_samples_widgets_setDialogButtons;
        this.dialogBut = netscape_samples_widgets_dialogBut;
        this.drag = netscape_samples_widgets_drag;
        this.startDrag = netscape_samples_widgets_startDrag;
        this.endDrag = netscape_samples_widgets_endDrag;
        this.setDrag = netscape_samples_widgets_setDrag;
        this.dObjects = netscape_samples_widgets_dObjects;
        this.dObjects();
    }

    /**
     * A private function -- doesn't need to use leading "_"
     * conventions, though it could...
     */
    function netscape_samples_widgets_dObjects() {
        // Note: dialogObjects array is placed into
        // netscape_samples_widgets namespace to avoid
        // conflicts
        if(!window.netscape_samples_widgets_dialogObjects) {
            window.netscape_samples_widgets_dialogObjects = new Array();
            window.netscape_samples_widgets_dialogObjects[0] = this;
        } else {
            window.netscape_samples_widgets_dialogObjects[window.netscape_samples_widgets_dialogObjects.length++] = this;
        }
    }

    /**
     * Opens the dialog with the currently set parameters
     * (writing the content to the content layer
     *  with the mimetype set to "text/html")
     *
     * Form fields and other items inside the content can be accessed via
     * <pre>
     * abstractDialog.win.con.document.
     * </pre>
     */
    function netscape_samples_widgets_openDialog(id) {
        _netscape_samples_widgets_sysout("OpenDialog::"+this.dialogTitle);

        this.win = new Object();
        this.win.doc = new Layer(100);
        this.win.doc.bgColor = '#000000';
        this.win.doc.moveTo(this.dialogX,this.dialogY);
        this.win.doc.d = this;
        this.win.ld = new Layer(100,this.win.doc);
        this.win.ld.bgColor = '#DDDDDD';
        this.win.ld.moveTo(-1,-1);
        this.win.lf = new Layer(100,this.win.doc);
        this.win.lf.bgColor = "#FFFFFF";
        this.win.lf.moveTo(1,1);
        this.win.lb = new Layer(100,this.win.doc);
        this.win.lb.bgColor = '#888888';
        this.win.lb.moveTo(2,2);
        this.win.lc = new Layer(100,this.win.doc);
        this.win.lc.bgColor = '#CCCCCC';
        this.win.lc.moveTo(2,2);
        this.win.lt = new Layer(100,this.win.doc);
        this.win.lt.bgColor = '#000084';
        this.win.lt.moveTo(4,4);
        this.win.lt.document.open("text/html");
        this.win.lt.document.writeln('<NOBR><FONT COLOR="#FFFFFF"><B>&nbsp; '+ this.dialogTitle +'</B></FONT>');
        this.win.lt.document.close();
        this.win.lt.dragLayer = this.win.doc;
        this.win.lt.onMouseOver = this.setDrag;
        this.win.temp = new Layer(100,this.win.doc);

        // Writes the content to the content layer
        // with the mimetype set to "text/html"
        this.win.temp.document.open("text/html");
        this.win.temp.document.writeln(this.dialogContent);
        this.win.temp.document.close();

        if(this.dialogW == null)
            this.boxW = this.win.temp.clip.width;
        else
            this.boxW = this.dialogW;

        this.win.con = new Layer(this.boxW,this.win.doc);
        this.win.con.bgColor = this.dialogBG;
        this.win.con.moveTo(4,25);
        this.win.con.document.open("text/html");
        this.win.con.document.writeln(this.dialogContent);
        this.win.con.document.close();

        // Checks to see if a source URL has been specified.
        if(this.dialogSRC != "URL")
            this.win.con.src = this.dialogSRC;;

        // Checks to see if dialogH has been set
        if(this.dialogH == null)
            this.boxH = this.win.con.clip.height;
        else
            this.boxH = this.dialogH;

        this.win.con.clip.height = this.boxH;

        if(this.win.lt.clip.width >  this.boxW)
            this.boxW = this.win.lt.clip.width;

        // Creates the dialog buttons
        this.dialogBut();

        if(this.win.con.clip.width > this.boxW) this.boxW = this.win.con.clip.width +5;
        this.win.con.clip.width  = this.boxW -4;
        this.win.doc.clip.width  = this.boxW +4;
        this.win.doc.clip.height = this.boxH +4;
        this.win.ld.clip.width   = this.boxW +4;
        this.win.ld.clip.height  = this.boxH +4;
        this.win.lf.clip.width   = this.boxW +2;
        this.win.lf.clip.height  = this.boxH +2;
        this.win.lb.clip.width   = this.boxW +1;
        this.win.lb.clip.height  = this.boxH +1;
        this.win.lc.clip.width   = this.boxW;
        this.win.lc.clip.height  = this.boxH;
        this.win.lt.clip.width   = this.boxW -4;
        this.win.lt.clip.height  = 20;
        this.win.con.visibility  = "inherit";
        this.win.ld.visibility   = "inherit";
        this.win.lf.visibility   = "inherit";
        this.win.lb.visibility   = "inherit";
        this.win.lc.visibility   = "inherit";
        this.win.lt.visibility   = "inherit";
        this.win.doc.visibility  = "inherit";
        //this.setDrag(this.win.lt, this.win.doc, id);
        window.captureEvents(Event.RESIZE);
        window.onresize=netscape_samples_widgets_resetDialog;
    }

    /**
     * Creates the dialog buttons and their container layer
     */
    function netscape_samples_widgets_dialogBut() {
        if(this.dialogButtons != false) {
            // If the dialog buttons are to be shown, create them
            this.win.lbut = new Layer(this.boxW,this.win.doc);
            this.win.lbut.moveTo(4,this.win.con.clip.height +30);
            this.win.lbut.document.open("text/html");
            this.win.lbut.document.writeln('<CENTER><NOBR><FORM NAME="dialogForm">&nbsp;<INPUT TYPE=button VALUE="   OK   "> <INPUT TYPE=button VALUE="Cancel" onClick="d.win.doc.visibility=\'hide\'; d.win=null;">&nbsp;</FORM></NOBR></CENTER>');
            this.win.lbut.document.close();

            if(this.win.lbut.clip.height > 35)
            this.win.lbut.clip.height -= 15;

            this.win.lbut.document.forms[0].elements[0].onClick = this.okButton;
            this.win.lbut.onMouseOver = this.okButtonFocus;
            this.win.lbut.abstractDialog = this;
            this.boxH = this.win.lt.clip.height + this.win.con.clip.height + this.win.lbut.clip.height +10;

            if(this.win.lbut.clip.width > this.boxW)
            this.boxW = this.win.lbut.clip.width +5;

            this.win.lbut.clip.width = this.boxW -4;
            this.win.lbut.visibility = "inherit";
            this.win.lt.butLayer = this.win.lbut;
        } else {
            // Otherwise set height appropriately.
            this.boxH = this.win.lt.clip.height + this.win.con.clip.height +6;
        }
    }

    /**
     * Creates the ok button
     */
    function netscape_samples_widgets_okButton(e) {
        eval(abstractDialog.dialogOK);
        abstractDialog.win.doc.visibility='hide'; 
        abstractDialog.win=null;
    }

    /**
     * Called when ok button gets focus
     */
    function netscape_samples_widgets_okButtonFocus(e) {
        // GLOBALS ALERT!
        // This variable is global for the document, and NOT in
        // a namespace... Better architecture would mandate usage
        // of a namespace...
        abstractDialog = this.abstractDialog;
    }


    /********************************************************************
     * SETTER / GETTER methods below
     */

    /**
     * Sets the dialog contents
     */
    function netscape_samples_widgets_setDialogContent(str) {
        this.dialogContent = str;
    }

    /**
     * Sets the dialog title
     */
    function netscape_samples_widgets_setDialogTitle(str) {
        this.dialogTitle = str;
    }

    /**
     * Sets the dialogOK string...
     */
    function netscape_samples_widgets_setDialogOK(str) { 
        this.dialogOK = str;
    }

    /**
     * Sets the dialogX Position
     */
    function netscape_samples_widgets_setDialogX(i) {
        this.dialogX = i;
    }

    /**
     * Sets the dialogY Position
     */
    function netscape_samples_widgets_setDialogY(i) {
        this.dialogY = i;
    }

    /**
     * Sets the dialog width
     */
    function netscape_samples_widgets_setDialogW(i) {
        this.dialogW = i;
    }

    /**
     * Sets the dialog height
     */
    function netscape_samples_widgets_setDialogH(i) {
        this.dialogH = i;
    }

    /**
     * Sets the dialog background
     */
    function netscape_samples_widgets_setDialogBG(str) {
        this.dialogBG = str;
    }

    /**
     * Sets the dialog display / hide dialog buttons boolean flag
     */
    function netscape_samples_widgets_setDialogButtons(boo) {
        this.dialogButtons = boo;
    }

    /**
     * Sets the drag session
     */
    function netscape_samples_widgets_setDrag() {
        d = this;
        d.dragLayer = this.dragLayer;
        d.butLayer = this.butLayer;
        d.captureEvents(Event.MOUSEUP|Event.MOUSEDOWN|Event.MOUSEDRAG);
        d.onmousedown=netscape_samples_widgets_startDrag;
        d.onmouseup=netscape_samples_widgets_endDrag;
    }

    /**
     * Drags the window
     */
    function netscape_samples_widgets_drag(e) {
        if(d.butLayer) d.butLayer.visibility = "hide";
        d.dragLayer.moveBy(e.pageX-d.offX,e.pageY-d.offY);
        d.offX = e.pageX;
        d.offY = e.pageY;
        d.dragged = true;
    }

    /**
     * Initiates dragging of the window
     */
    function netscape_samples_widgets_startDrag(e) {
        d.dragLayer.captureEvents(Event.MOUSEMOVE);
        d.dragLayer.onmousemove=netscape_samples_widgets_drag; 
        d.offX=e.pageX;
        d.offY=e.pageY;
    }

    /**
     * Ends dragging of the window
     */
    function netscape_samples_widgets_endDrag(e) {
        d.dragLayer.onmousemove=0;
        if(d.dragged == true) {
        d.dragLayer.visibility="hide"; 
        if(d.butLayer) d.butLayer.visibility = "inherit";
        setTimeout('if(d.dragLayer) d.dragLayer.visibility="inherit";',1);
        //d.dragLayer.releaseEvents(Event.MOUSEDOWN|Event.MOUSEUP|Event.MOUSEMOVE|Event.MOUSEDRAG);
        d.dragged = false;
        }
        if(d.lbut) d.lbut.visibility = "inherit";
    }

    /**
     * Resets dialog (visibility, etc) after a browser
     * resize event
     */
    function netscape_samples_widgets_resetDialog(e) {
        for(var i=0; i < window.netscape_samples_widgets_dialogObjects.length; i++) {
            if(window.netscape_samples_widgets_dialogObjects[i].win) window.netscape_samples_widgets_dialogObjects[i].openDialog();
        }
    }

    /**
     * This is a sample function which can be called directly to create
     * a simple dialog.  Illustrates how to get form-field data from the
     * dialog:
     * <pre>
     * abstractDialog.win.con.document
     * </pre>
     * @see openDialog
     */
    function netscape_samples_widgets_exampleDialog() {
        var Dialog = new netscape_samples_widgets_dialog('foo');
        //Dialog.setDialogW(500);
        //Dialog.setDialogH(100);
        Dialog.setDialogBG("#DDDDDD");
        Dialog.setDialogX(10);
        Dialog.setDialogY(50);
        //Dialog.setDialogButtons(false);
        //Dialog.dialogSRC = "../";
        Dialog.setDialogContent('Enter some text');
        Dialog.setDialogContent('<CENTER><BR>Enter a local <B>filename</B>: <FORM><INPUT TYPE=FILE NAME="fileName" VALUE="" SIZE=40>&nbsp;</FORM></CENTER>');
        Dialog.setDialogTitle('Generate jsbdoc');
        Dialog.setDialogOK('alert("You entered: " + abstractDialog.win.con.document.forms[0].fileName.value)');
        Dialog.openDialog(1);
    }


    /**
     * This is a private function to output
     * text to the Java console.
     */
    function _netscape_samples_widgets_sysout(tempString) {
        // Commented out for non-debug mode
        //java.lang.System.out.println(tempString);
    }



   </JSB_CONSTRUCTOR>
</JSB>
